import time
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.common.exceptions import NoSuchElementException, TimeoutException
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.chrome.options import Options
from utils.scraping_utils import ScrapingUtils


class ScoutImageScraper:
    def __init__(self):
        chrome_options = Options()
        user_agent = ScrapingUtils.get_random_user_agent()
        chrome_options.add_argument(f"user-agent={user_agent}")

        self.driver = webdriver.Chrome()

    # Cookie modal window handler
    def handle_cookies(self):
        try:
            WebDriverWait(self.driver, 10).until(
                EC.visibility_of_element_located((By.CSS_SELECTOR, 'div[data-testid="as24-cmp-container"]'))
            )
            accept_button = self.driver.find_element(By.CSS_SELECTOR,
                                                     'button[data-testid="as24-cmp-accept-all-button"]')
            accept_button.click()
            time.sleep(2)
        except TimeoutException:
            print("Cookie modal not found or already accepted.")
        except Exception as e:
            print(f"Error handling cookies: {e}")

    def extract_and_download_images(self, url, subfolder_name):
        print(f"Processing URL: {url}")
        self.driver.get(url)
        self.handle_cookies()
        slide_number = 1
        while True:
            try:
                image_element = self.driver.find_element(By.CSS_SELECTOR,
                                                         f'div[aria-label="Go to Slide {slide_number}"] picture img')
                image_url = image_element.get_attribute('src')
                if image_url:
                    # Make request with rand user agent and save with uuid (collision avoiding)
                    file_path = ScrapingUtils.download_image_with_unique_name(image_url, subfolder_name, headers={
                        'User-Agent': ScrapingUtils.get_random_user_agent()})
                    if file_path:
                        print(f"Image saved successfully to {file_path}")
                    else:
                        print(f"Failed to download image from {image_url}")
                # Gallery sliding logic
                next_button = self.driver.find_element(By.CSS_SELECTOR, 'button[aria-label="Next Slide"]')
                next_button.click()
                slide_number += 1
                time.sleep(0.6)
            except NoSuchElementException:
                print("No more slides found. Moving to the next URL...")
                break

    def close_driver(self):
        self.driver.quit()
