from bs4 import BeautifulSoup
from utils.scraping_utils import ScrapingUtils


class ScoutLinksScraper:
    def __init__(self, base_url="https://autoscout24.com/"):
        self.base_url = base_url

    def extract_links(self, html_content):
        soup = BeautifulSoup(html_content, 'html.parser')
        links = []
        for article in soup.find_all("article", {"data-testid": "list-item"}):
            a_tag = article.find("a", href=True)
            if a_tag:
                full_link = ScrapingUtils.get_full_url(self.base_url, a_tag['href'])
                links.append(full_link)
        return links

    def scrape_all_links(self, start_url):
        all_links = []
        page_number = 1
        while True:
            current_page_url = f"{start_url}&page={page_number}"
            # Fetching content via randomized user agents
            headers = {'User-Agent': ScrapingUtils.get_random_user_agent()}
            page_content = ScrapingUtils.get_page_content(current_page_url, headers=headers)
            if page_content:
                links = self.extract_links(page_content)
                if not links:
                    break  # Break the loop if no links are found on the page
                all_links.extend(links)
                print(f"Scraped {len(links)} links from page {page_number}")
                page_number += 1
            else:
                break  # Break if failed to retrieve page content
        return all_links
