import time

from bs4 import BeautifulSoup
from utils.scraping_utils import ScrapingUtils


class MotoHuntImageScraper:
    def __init__(self, base_url="https://motohunt.com"):
        self.base_url = base_url

    def extract_and_download_images(self, page_url, subfolder_name):
        headers = {'User-Agent': ScrapingUtils.get_random_user_agent()}
        page_content = ScrapingUtils.get_page_content(page_url, headers=headers)

        if not page_content:
            print(f"Error while processing page {page_url}")
            return

        soup = BeautifulSoup(page_content, 'html.parser')
        carousel_inner = soup.find("div", class_="carousel-inner")
        if carousel_inner is None:
            print("No images found on page.")
            return

        for carousel_item in carousel_inner.find_all("div", class_=["carousel-item", "carousel-item active"]):
            img_tag = carousel_item.find("img")
            if img_tag and img_tag.get("data-src"):
                image_url = img_tag["data-src"]
                file_path = ScrapingUtils.download_image_with_unique_name(image_url, subfolder_name, headers)
                time.sleep(0.3)
                if file_path:
                    print("Image downloaded successfully:", file_path)
                else:
                    print(f"Failed to download image {image_url}")
