from bs4 import BeautifulSoup
from utils.scraping_utils import ScrapingUtils


class MotoHuntLinksScraper:
    def __init__(self, base_url="https://motohunt.com"):
        self.base_url = base_url

    def extract_links(self, html_content):
        soup = BeautifulSoup(html_content, 'html.parser')
        links = []
        for card_body in soup.find_all("div", class_="card-body nolinkcolor"):
            a_tag = card_body.find("a", href=True)
            if a_tag:
                full_link = ScrapingUtils.get_full_url(self.base_url, a_tag['href'])
                links.append(full_link)
        return links

    # Pagination handling
    def find_next_page_link(self, html_content):
        soup = BeautifulSoup(html_content, 'html.parser')
        next_link_tag = soup.find("span", id="results-text").find("a", id="next", href=True)
        if next_link_tag:
            return ScrapingUtils.get_full_url(self.base_url, next_link_tag['href'])
        return None

    def scrape_all_links(self, start_url):
        all_links = []
        next_page = start_url
        while next_page:
            # Requests via random user agents
            headers = {'User-Agent': ScrapingUtils.get_random_user_agent()}
            page_content = ScrapingUtils.get_page_content(next_page, headers=headers)
            if page_content:
                links = self.extract_links(page_content)
                all_links.extend(links)
                next_page = self.find_next_page_link(page_content)
            else:
                break
        return all_links
