import os
import random
import uuid
import requests
from datetime import datetime


class ScrapingUtils:
    # Const list of user agents
    USER_AGENTS = [
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.3",
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/16.6 Mobile/15E148 Safari/604.",
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/17.2 Safari/605.1.1",
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/121.0.0.0 Safari/537.3",
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36 Edg/120.0.0.",
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36 OPR/106.0.0.",
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/119.0.0.0 Safari/537.3",
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/117.0.0.0 Safari/537.36 Edg/117.0.2045.6"
    ]

    @staticmethod
    def get_random_user_agent():
        return random.choice(ScrapingUtils.USER_AGENTS)

    # Getting full url combining domain (base url) and <a href> of element
    @staticmethod
    def get_full_url(base_url, partial_url):
        return base_url + partial_url if partial_url.startswith("/") else partial_url

    # Make HTTP GET requests with optional headers (somehow headers options looks stupid for me but ok)
    @staticmethod
    def get_page_content(url, headers=None):
        try:
            response = requests.get(url, headers=headers)
            response.raise_for_status()
            return response.content
        except requests.exceptions.HTTPError as e:
            if response.status_code == 403:
                print(f"Code 403. You may be blocked / forced session close")
            else:
                print(f"HTTP error: {e}")
                return None
        except requests.exceptions.RequestException as e:
            print(f"Error fetching page: {e}")
            return None

    @staticmethod
    def image_dir_for_session(subfolder_name):
        # Determine the parent directory of the 'manager' folder
        parent_of_manager = os.path.abspath(os.path.join(os.getcwd(), os.pardir))

        # Create 'Images' directory in the parent directory of 'manager'
        images_directory = os.path.join(parent_of_manager, "Images")

        # Create subfolders within 'Images'
        full_folder_path = os.path.join(images_directory, subfolder_name)
        if not os.path.exists(full_folder_path):
            os.makedirs(full_folder_path)

        return full_folder_path

    # Method for proper image saving with uuid
    @staticmethod
    def download_image_with_unique_name(image_url, subfolder_name, headers=None):
        # Downloads an image from a URL and saves it with a unique filename in a subfolder
        folder_path = ScrapingUtils.image_dir_for_session(subfolder_name)

        try:
            response = requests.get(image_url, headers=headers)
            response.raise_for_status()
            image_extension = os.path.splitext(image_url)[-1]
            # Generates a unique filename for the image to avoid collision
            # bLinksFolderName_uuid_imageFormatFrom<a>
            new_filename = f"{subfolder_name}_{uuid.uuid4()}{image_extension}"  # Keep original naming format
            file_path = os.path.join(folder_path, new_filename)

            with open(file_path, 'wb') as file:
                file.write(response.content)
            print("Image downloaded successfully:", file_path)
            return file_path
        except requests.exceptions.RequestException as e:
            print(f"Error downloading image {image_url}: {e}")
            return None
